/***************************************************************************
                          kmasqdock.cpp  -  description
                             -------------------
    begin                : Thu Mar 22 2001
    copyright            : (C) 2001 by Stephan de Georgio
    email                : kmasqdialer@stephan.co.uk
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "kmasqdock.h"

#include <klocale.h>
#include <qstring.h>
#include <qpainter.h>

KMasqDock::KMasqDock()
{
	iconLoader = new KIconLoader();
	setPixmap(iconLoader->loadIcon("kmasqdialer-dock1", KIcon::MainToolbar));
	contextMenu()->insertItem(i18n("&Hide"), 1001);
	contextMenu()->insertSeparator();
	contextMenu()->insertItem(i18n("&Dial"), 1002);
	contextMenu()->setItemEnabled(1002, false);
	contextMenu()->connectItem(1001, this, SLOT(slotHide()));
	contextMenu()->connectItem(1002, this, SLOT(slotDial()));
	dialed = false;
	connect(contextMenu(), SIGNAL(activated(int)), this, SLOT(slotItemSelected(int)));
	bytesIn = lastBytesIn = bytesOut = lastBytesOut = 0;
}

KMasqDock::~KMasqDock()
{
}

void KMasqDock::slotHide()
{
	if(contextMenu()->text(1001) == i18n("&Hide"))
	{
		contextMenu()->changeItem(1001, i18n("&Show"));
		emit sigChangeStatus("hide");
	}
	else
	{
		contextMenu()->changeItem(1001, i18n("&Hide"));
		emit sigChangeStatus("show");
	}
}

void KMasqDock::slotDial()
{
	if(contextMenu()->text(1002) == i18n("&Dial"))
	{
		emit sigChangeStatus("dial");
	}
	else
	{
		emit sigChangeStatus("hangup");
	}
}

void KMasqDock::slotSetStatus(const char *status)
{
	QString temp(status);
	if(temp == "dialed")
	{
		contextMenu()->setItemEnabled(1002, true);
		contextMenu()->changeItem(1002, i18n("&Hang Up"));
		if(dialed == false)
		{
			setPixmap(iconLoader->loadIcon("kmasqdialer-dock2", KIcon::MainToolbar));
		}
		dialed = true;
	}
	if(temp == "hungup")
	{
		contextMenu()->setItemEnabled(1002, true);
		contextMenu()->changeItem(1002, i18n("&Dial"));
		if(dialed == true)
		{
			setPixmap(iconLoader->loadIcon("kmasqdialer-dock1", KIcon::MainToolbar));
		}
		dialed = false;
		bytesIn = lastBytesIn = bytesOut = lastBytesOut = 0;
		update();
	}
	if(temp == "connected")
	{
		contextMenu()->setItemEnabled(1002, true);
		contextMenu()->changeItem(1002, i18n("&Dial"));
	}
	if(temp == "disconnected")
	{
		contextMenu()->setItemEnabled(1002, false);
		contextMenu()->changeItem(1002, i18n("&Dial"));
		if(dialed == true)
		{
			setPixmap(iconLoader->loadIcon("kmasqdialer-dock1", KIcon::MainToolbar));
		}
		dialed = false;
	}
	if(temp == "minimized")
	{
		contextMenu()->changeItem(1001, i18n("&Show"));
	}
}

void KMasqDock::slotItemSelected(int id)
{
	if(id == -18)
		emit sigChangeStatus("quit");
}

void KMasqDock::mousePressEvent(QMouseEvent * event)
{
	if(event->button() == QMouseEvent::LeftButton)
	{
		slotHide();
	}
	if(event->button() == QMouseEvent::RightButton)
	{
		contextMenu()->exec(QCursor::pos());
	}
}

void KMasqDock::paintEvent(QPaintEvent *)
{
	QPainter paintDock(this);
	if(dialed)
		paintDock.drawPixmap(0, 1, iconLoader->loadIcon("kmasqdialer-dock2", KIcon::MainToolbar));
	else
		paintDock.drawPixmap(0, 1, iconLoader->loadIcon("kmasqdialer-dock1", KIcon::MainToolbar));
	paintDock.setPen(Qt::red);
	paintDock.drawRect(4, 19, 2, 2);
	paintDock.drawRect(16, 19, 2, 2);
	if(bytesIn != lastBytesIn)
	{
		paintDock.setPen(Qt::green);
		paintDock.drawRect(4, 19, 2, 2);
	}
	if(bytesOut != lastBytesOut)
	{
		paintDock.setPen(Qt::green);
		paintDock.drawRect(16, 19, 2, 2);
	}
}

void KMasqDock::slotUpdateDock(float bytesInTemp, float lastBytesInTemp, float bytesOutTemp, float lastBytesOutTemp)
{
	bytesIn = bytesInTemp;
	lastBytesIn = lastBytesInTemp;
	bytesOut = bytesOutTemp;
	lastBytesOut = lastBytesOutTemp;
	update();
}
